@@ -10,8 +10,8 @@ TODO:
     - Pre-built prompts
     - Proxy
 """
-__version__ = '0.1.0'
-__all__ = ['auth', 'config', 'convo', 'cli']
+__version__ = '0.1.2'
+__all__ = ['core', 'config', 'convo', 'cli']
 
 if __name__ == '__main__':
     for module in __all__:
